| Title: | API Wrapper for 'Ipeadata' |
|---|---|
| Description: | Provides direct access to the macroeconomic, financial, and regional database maintained by the Institute for Applied Economic Research (Ipea) via the Ipeadata API. For more information, see <https://www.ipeadata.gov.br/>. |
| Authors: | Luiz Eduardo Gomes [aut, cre] (ORCID: <https://orcid.org/0000-0001-8968-5947>), Daniel Herszenhut [ctb] (ORCID: <https://orcid.org/0000-0001-8066-1105>), Instituto de Pesquisa Econômica Aplicada (Ipea) [cph, fnd] |
| Maintainer: | Luiz Eduardo Gomes <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-05-28 14:42:24 UTC |
| Source: | https://github.com/ipea/ipeadatar |
Returns a list of available series from the Ipeadata API.
available_series(language = c("en", "br"), label = TRUE)available_series(language = c("en", "br"), label = TRUE)
language |
A character string specifying the language. Available
options are English ( |
label |
Logical. If |
A data frame containing the Ipeadata code, name, theme, source, frequency, last update, and activity status of available series.
The original language of the available series names is preserved.
Returns a list of available subjects from the Ipeadata API.
available_subjects(language = c("en", "br"), label = TRUE)available_subjects(language = c("en", "br"), label = TRUE)
language |
A character string specifying the language. Available
options are English ( |
label |
Logical. If |
A data frame containing the subject code and subject name.
Returns a list of available Brazilian territorial divisions from the Ipeadata API.
available_territories(language = c("en", "br"), label = TRUE)available_territories(language = c("en", "br"), label = TRUE)
language |
A character string specifying the language. Available
options are English ( |
label |
Logical. If |
A data frame containing the unit type, code, name, and area (in km²) of Brazilian territorial divisions.
Returns the data associated with requested Ipeadata series.
ipeadata(code, language = c("en", "br"), label = TRUE, quiet = FALSE)ipeadata(code, language = c("en", "br"), label = TRUE, quiet = FALSE)
code |
A character vector of Ipeadata series codes. |
language |
A character string specifying the language. Available
options are English ( |
label |
Logical. If |
quiet |
Logical. If |
A data frame containing the Ipeadata code, date, value, territorial unit name, and territorial code of the requested series.
Ipeadata codes may be obtained using available_series().
This package uses the Ipeadata API: https://www.ipeadata.gov.br/
available_series(), available_territories()
data <- ipeadata( code = "PRECOS12_IPCA12", language = "en" )data <- ipeadata( code = "PRECOS12_IPCA12", language = "en" )
Returns metadata information for requested Ipeadata series.
metadata(code, language = c("en", "br"), label = TRUE, quiet = FALSE)metadata(code, language = c("en", "br"), label = TRUE, quiet = FALSE)
code |
A character vector of Ipeadata series codes. |
language |
A character string specifying the language. Available
options are English ( |
label |
Logical. If |
quiet |
Logical. If |
A data frame containing metadata for the requested Ipeadata series, including code, name, comments, last update, theme, source, frequency, unit, multiplier, status, subject code, and country code.
The original language of series names and comments is preserved.
Ipeadata codes may be obtained using available_series().
This package uses the Ipeadata API: https://www.ipeadata.gov.br/
available_series(), available_subjects(),
available_territories()
meta <- metadata(code = "PRECOS12_IPCA12")meta <- metadata(code = "PRECOS12_IPCA12")
Searches for Ipeadata series matching the provided terms.
search_series(terms = NULL, language = c("en", "br"), label = TRUE)search_series(terms = NULL, language = c("en", "br"), label = TRUE)
terms |
A character vector of search terms. |
language |
A character string specifying the language. Available
options are English ( |
label |
Logical. If |
A data frame containing the Ipeadata code, name, theme, source, frequency, last update, and activity status of the matched series.
The original language of the series names is preserved.
search_series(terms = "rural")search_series(terms = "rural")